Style Change: NULL->nullptr
DOCS_PREVIEW= https://skia.org/?cl=1316233002

Review URL: https://codereview.chromium.org/1316233002
diff --git a/tests/OSPathTest.cpp b/tests/OSPathTest.cpp
index facc6ad..3276145 100644
--- a/tests/OSPathTest.cpp
+++ b/tests/OSPathTest.cpp
@@ -86,8 +86,8 @@
     SkString baseOfDir = SkOSPath::Basename(dir.c_str());
     REPORTER_ASSERT(reporter, baseOfDir.size() == 0);
 
-    // Basename of NULL is an empty string.
-    SkString empty = SkOSPath::Basename(NULL);
+    // Basename of nullptr is an empty string.
+    SkString empty = SkOSPath::Basename(nullptr);
     REPORTER_ASSERT(reporter, empty.size() == 0);
 
     // File in root dir
@@ -99,7 +99,7 @@
     filename.reset();
     test_dir_with_file(reporter, dir, filename);
 
-    // Test that NULL can be used for the directory and filename.
-    SkString emptyPath = SkOSPath::Join(NULL, NULL);
+    // Test that nullptr can be used for the directory and filename.
+    SkString emptyPath = SkOSPath::Join(nullptr, nullptr);
     REPORTER_ASSERT(reporter, emptyPath.isEmpty());
 }